aboutsummaryrefslogtreecommitdiffstats
path: root/src/libimcv/tcg/pts/pts.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/libimcv/tcg/pts/pts.c')
-rw-r--r--src/libimcv/tcg/pts/pts.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/libimcv/tcg/pts/pts.c b/src/libimcv/tcg/pts/pts.c
index 71acfdac6..ef5218395 100644
--- a/src/libimcv/tcg/pts/pts.c
+++ b/src/libimcv/tcg/pts/pts.c
@@ -401,18 +401,18 @@ static char* extract_platform_info(void)
memcpy(buf, value, value_len);
buf[value_len] = ' ';
- /* open a pipe stream for reading the output of the uname commmand */
- file = popen("/bin/uname -p" , "r");
+ /* open a pipe stream for reading the output of the arch commmand */
+ file = popen("/usr/bin/arch" , "r");
if (!file)
{
- DBG2(DBG_IMC, "failed to run uname command");
+ DBG2(DBG_IMC, "failed to run arch command");
return NULL;
}
/* Read the output the uname command */
if (!fgets(buf + value_len + 1, BUF_LEN - value_len - 2, file))
{
- DBG2(DBG_IMC, "failed to read output of uname command");
+ DBG2(DBG_IMC, "failed to read output of arch command");
pclose(file);
return NULL;
}
@@ -401,18 +401,18 @@ static char* extract_platform_info(void)
return NULL;
}
- /* Read the output the uname command */
+ /* Read the output the arch command */
if (!fgets(buf + value_len + 1, BUF_LEN - value_len - 2, file))
{